@@ -12,10 +12,10 @@ from botocore.exceptions import ClientError
 
 from ecs_composex.common import LOG
 from ecs_composex.common.aws import (
-    find_aws_resource_arn_from_tags_api,
     define_lookup_role_from_info,
+    find_aws_resource_arn_from_tags_api,
 )
-from ecs_composex.dynamodb.dynamodb_params import TABLE_NAME, TABLE_ARN
+from ecs_composex.dynamodb.dynamodb_params import TABLE_ARN, TABLE_NAME
 
 
 def get_table_config(table_arn, session):
