@@ -8,10 +8,9 @@ Functions to pass permissions to Services to access S3 buckets.
 import re
 from json import dumps
 
-from troposphere import FindInMap, Sub, Ref
-from troposphere import AWS_PARTITION
+from troposphere import AWS_PARTITION, FindInMap, Ref, Sub
 
-from ecs_composex.common import LOG, keyisset, add_parameters
+from ecs_composex.common import LOG, add_parameters, keyisset
 from ecs_composex.common.compose_resources import get_parameter_settings
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.kms.kms_perms import ACCESS_TYPES as KMS_ACCESS_TYPES
@@ -21,11 +20,7 @@ from ecs_composex.resource_settings import (
     get_selected_services,
 )
 from ecs_composex.s3.s3_aws import lookup_bucket_config
-from ecs_composex.s3.s3_params import (
-    MOD_KEY,
-    S3_BUCKET_NAME,
-    S3_BUCKET_ARN,
-)
+from ecs_composex.s3.s3_params import MOD_KEY, S3_BUCKET_ARN, S3_BUCKET_NAME
 from ecs_composex.s3.s3_perms import ACCESS_TYPES
 
 
@@ -78,17 +73,7 @@ def assign_new_bucket_to_services(bucket, res_root_stack, nested=False):
         select_services = get_selected_services(bucket, target)
         access = {objects_key: "RW", bucket_key: "ListOnly"}
         if select_services:
-            if not keyisset("access", target[3]):
-                LOG.warning(
-                    f"No permissions associated for {target[0].name}. Setting default."
-                )
-            elif isinstance(target[3], str):
-                LOG.warning(
-                    f"Permissions for bucket must be a map with {bucket_key} and {objects_key}"
-                    " defined. Setting to default"
-                )
-            else:
-                access = target[3]
+            access = target[3]
             add_parameters(
                 target[0].template,
                 params_to_add,
